<?php

declare(strict_types = 1);

/**
 * Copyright (C) 2024 PRONOVIX GROUP.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */
namespace Drupal\symfony_webhook_receiver_example\RemoteEvent;

use Drupal\Core\DependencyInjection\AutowireTrait;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\Attribute\Autowire;
use Symfony\Component\RemoteEvent\Attribute\AsRemoteEventConsumer;
use Symfony\Component\RemoteEvent\Consumer\ConsumerInterface;
use Symfony\Component\RemoteEvent\RemoteEvent;

/**
 * Example webhook consumer registered via path and attribute-based discovery.
 *
 * @internal This class is not part of the module's public programming API.
 */
#[AsRemoteEventConsumer('example_auto_discover')]
final class ExampleAutoDiscoverConsumer implements ConsumerInterface {

  use AutowireTrait;

  public function __construct(
    #[Autowire(service: 'logger.channel.symfony_webhook_receiver_example.example_auto_discover_consumer')]
    private readonly LoggerInterface $logger,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function consume(RemoteEvent $event): void {
    $this->logger->debug(print_r([
      'name' => $event->getName(),
      'id' => $event->getId(),
      'payload' => $event->getPayload(),
    ], TRUE));
  }

}
