<?php

declare(strict_types = 1);

/**
 * Copyright (C) 2024 PRONOVIX GROUP.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */
namespace Drupal\symfony_webhook_receiver;

use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceProviderInterface;
use Drupal\symfony_webhook_receiver\DependencyInjection\RegisterAsRemoteEventConsumerAttributeCompilerPass;
use Drupal\symfony_webhook_receiver\DependencyInjection\RegisterRemoveEventConsumersCompilerPass;
use Drupal\symfony_webhook_receiver\DependencyInjection\RegisterWebhookRequestParsersCompilerPass;

/**
 * Module specific service provider.
 *
 * @internal This class is not part of the module's public programming API.
 */
final class SymfonyWebhookReceiverServiceProvider implements ServiceProviderInterface {

  /**
   * {@inheritdoc}
   */
  public function register(ContainerBuilder $container): void {
    // Priority 200 to execute before AttributeAutoconfigurationPass which has
    // priority 100. See symfony/dependency-injection/Compiler/PassConfig.php.
    $container->addCompilerPass(new RegisterAsRemoteEventConsumerAttributeCompilerPass(), priority: 200);
    $container->addCompilerPass(new RegisterRemoveEventConsumersCompilerPass());
    $container->addCompilerPass(new RegisterWebhookRequestParsersCompilerPass());
  }

}
